==> fallball-0.1.10.tar.gz: fallball-0.1.10/fallball/fallballapp/serializers.py <==
from random import randint

from django.contrib.auth.models import User
from rest_framework import serializers as rest_serializers
from rest_framework.authtoken.models import Token
from rest_framework.exceptions import ValidationError

from fallballapp.models import Client, ClientUser, Reseller


class StorageResellerSerializer(rest_serializers.HyperlinkedModelSerializer):
    """
    Auxiliary serializer in order to make nested json: "storage": {"usage","limit"}
    """
    usage = rest_serializers.SerializerMethodField()

    class Meta:
        model = Reseller
        fields = ('usage', 'limit')

    def get_usage(self, obj):
        return obj.get_usage()


class ResellerSerializer(rest_serializers.HyperlinkedModelSerializer):
    storage = StorageResellerSerializer(source='*')
    clients_amount = rest_serializers.SerializerMethodField()
    token = rest_serializers.SerializerMethodField()

    class Meta:
        model = Reseller
        fields = ('id', 'token', 'clients_amount', 'storage')

    def create(self, validated_data):
        """
        This method is overwritten in order to create User object and associate it with reseller.
        This operation is needed to create token for reseller
        """
        if User.objects.filter(username=validated_data['id']).exists():
            raise ValidationError('Reseller with such id is already created')

        user = User.objects.create(username=validated_data['id'])
        return Reseller.objects.create(owner=user, **validated_data)

    def get_clients_amount(self, obj):
        return obj.get_clients_amount()

    def get_token(self, obj):
        """
        As token exists inside User object, we need to get it to show it with particular reseller
        """
        token = Token.objects.filter(user=obj.owner).first()
        return token.key if token else None


class StorageClientSerializer(rest_serializers.HyperlinkedModelSerializer):
    usage = rest_serializers.SerializerMethodField()

    class Meta:
        model = Client
        fields = ('usage', 'limit')

    def get_usage(self, obj):
        return obj.get_usage()


class ClientSerializer(rest_serializers.HyperlinkedModelSerializer):
    storage = StorageClientSerializer(source='*')
    users_amount = rest_serializers.SerializerMethodField()

    class Meta:
        model = Client
        fields = ('id', 'creation_date', 'users_amount', 'storage')

    def create(self, validated_data):
        """
        Method is overwritten as we need to associate user with reseller
        """
        return Client.objects.create(reseller=self.initial_data['reseller'], **validated_data)

    def get_users_amount(self, obj):
        return obj.get_users_amount()


class StorageClientUserSerializer(rest_serializers.HyperlinkedModelSerializer):

    class Meta:
        model = ClientUser
        fields = ('usage', 'limit')


class ClientUserSerializer(rest_serializers.ModelSerializer):
    storage = StorageClientUserSerializer(source='*')
    admin = rest_serializers.BooleanField()

    class Meta:
        model = ClientUser
        fields = ('id', 'client', 'password', 'storage', 'admin')

    def create(self, validated_data):
        # Usage is random but not more than limit
        usage = randint(0, validated_data['limit'])
        user = User.objects.create_user(username=validated_data['id'],
                                        password=validated_data['password'])
        return ClientUser.objects.create(usage=usage, user=user, **validated_data)


class UserSerializer(rest_serializers.ModelSerializer):
    pass

==> fallball-0.1.14.tar.gz: fallball-0.1.14/fallball/fallballapp/serializers.py <==
from random import randint

from django.contrib.auth.models import User
from rest_framework import serializers as rest_serializers
from rest_framework.authtoken.models import Token
from rest_framework.exceptions import ValidationError

from fallballapp.models import Application, Client, ClientUser, Reseller
from fallballapp.utils import get_app_username


class AuthorizationSerializer(rest_serializers.HyperlinkedModelSerializer):
    token = rest_serializers.SerializerMethodField()

    def get_token(self, obj):
        """
        As token exists inside User object, we need to get it to show it with particular reseller
        """
        token = Token.objects.filter(user=obj.owner).first()
        return token.key if token else None


class ApplicationSerializer(AuthorizationSerializer):
    entrypoint = rest_serializers.SerializerMethodField()

    class Meta:
        model = Application
        fields = ('id', 'entrypoint', 'token')

    def get_entrypoint(self, obj):
        return 'https://{}.connector.fallball.io/api/v1'.format(obj.id)

    def create(self, validated_data):
        if User.objects.filter(username=validated_data['id']).exists():
            raise ValidationError('Application with such id is already created')

        user = User.objects.create(username=validated_data['id'])
        return Application.objects.create(owner=user, **validated_data)


class StorageResellerSerializer(rest_serializers.HyperlinkedModelSerializer):
    """
    Auxiliary serializer in order to make nested json: "storage": {"usage","limit"}
    """
    usage = rest_serializers.SerializerMethodField()

    class Meta:
        model = Reseller
        fields = ('usage', 'limit')

    def get_usage(self, obj):
        return obj.get_usage()


class ResellerSerializer(AuthorizationSerializer):
    storage = StorageResellerSerializer(source='*')
    clients_amount = rest_serializers.SerializerMethodField()

    class Meta:
        model = Reseller
        fields = ('name', 'token', 'clients_amount', 'storage')

    def create(self, validated_data):
        """
        This method is overwritten in order to create User object and associate it with reseller.
        This operation is needed to create token for reseller
        """
        application_id = self.initial_data['application'].id
        reseller_name = validated_data['name']
        username = '{application_id}.{reseller_name}'.format(application_id=application_id,
                                                             reseller_name=reseller_name)

        if User.objects.filter(username=username).exists():
            raise ValidationError('Reseller with such name is already created')

        user = User.objects.create(username=username)
        return Reseller.objects.create(owner=user, application=self.initial_data['application'],
                                       **validated_data)

    def get_clients_amount(self, obj):
        return obj.get_clients_amount()


class StorageClientSerializer(rest_serializers.HyperlinkedModelSerializer):
    usage = rest_serializers.SerializerMethodField()

    class Meta:
        model = Client
        fields = ('usage', 'limit')

    def get_usage(self, obj):
        return obj.get_usage()


class ClientSerializer(rest_serializers.HyperlinkedModelSerializer):
    storage = StorageClientSerializer(source='*')
    users_amount = rest_serializers.SerializerMethodField()

    class Meta:
        model = Client
        fields = ('name', 'creation_date', 'users_amount', 'storage')

    def create(self, validated_data):
        """
        Method is overwritten as we need to associate user with reseller
        """
        return Client.objects.create(reseller=self.initial_data['reseller'], **validated_data)

    def get_users_amount(self, obj):
        return obj.get_users_amount()


class StorageClientUserSerializer(rest_serializers.HyperlinkedModelSerializer):

    class Meta:
        model = ClientUser
        fields = ('usage', 'limit')


class ClientUserSerializer(rest_serializers.ModelSerializer):
    storage = StorageClientUserSerializer(source='*')
    admin = rest_serializers.BooleanField()

    class Meta:
        model = ClientUser
        fields = ('email', 'client', 'password', 'storage', 'admin')

    def create(self, validated_data):
        # Usage is random but not more than limit
        usage = randint(0, validated_data['limit'])

        username = get_app_username(self.initial_data['application_id'], validated_data['email'])
        user = User.objects.create_user(username=username,
                                        password=validated_data['password'])
        return ClientUser.objects.create(usage=usage, user=user, **validated_data)


class UserSerializer(rest_serializers.ModelSerializer):
    pass
